@@ -342,7 +342,7 @@ class IBDAWG:
             if (len(sNewWord) + len(sRemain) == len(oSuggResult.sWord)) and oSuggResult.sWord.lower().startswith(sNewWord.lower()) and self.isValid(sRemain):
                 if self.sLangCode == "fr" and sNewWord.lower() in ("l", "d", "n", "m", "t", "s", "c", "j", "qu", "lorsqu", "puisqu", "quoiqu", "jusqu", "quelqu") and sRemain[0:1] in cp.aVowel:
                     oSuggResult.addSugg(sNewWord+"’"+sRemain)
-                if (len(sNewWord) > 1 and len(sRemain) > 1) or sNewWord in ("a", "à", "y") or sRemain in ("a", "à", "y"):
+                if (len(sNewWord) > 1 and len(sRemain) > 1) or sNewWord in "aày" or sRemain in "aày":
                     oSuggResult.addSugg(sNewWord+" "+sRemain)
         if nDist > oSuggResult.nDistLimit:
             return
@@ -354,7 +354,7 @@ class IBDAWG:
                 if nMaxHardRepl and self.isNgramsOK(cChar+sRemain[1:2]):
                     self._suggest(oSuggResult, sRemain[1:], nMaxSwitch, nMaxDel, nMaxHardRepl-1, nMaxJump, nDist+1, nDeep+1, jAddr, sNewWord+cChar, True)
                 if nMaxJump:
-                    self._suggest(oSuggResult, sRemain, nMaxSwitch, nMaxDel, nMaxHardRepl, nMaxJump-1, nDist+1, nDeep+1, jAddr, sNewWord+cChar, True)
+                    self._suggest(oSuggResult, sRemain, nMaxSwitch, nMaxDel, nMaxHardRepl, nMaxJump-1, nDist+1, nDeep+1, jAddr, sNewWord+cChar, True) # True for avoiding loop?
         if not bAvoidLoop: # avoid infinite loop
             if len(sRemain) > 1:
                 if cCurrent == sRemain[1:2]:
@@ -389,53 +389,12 @@ class IBDAWG:
             return True
         return sChars in self.a2grams
 
-    #@timethis
-    def suggest2 (self, sWord, nSuggLimit=10):
-        "returns a set of suggestions for <sWord>"
-        sWord = cp.spellingNormalization(sWord)
-        sPfx, sWord, sSfx = cp.cut(sWord)
-        oSuggResult = SuggResult(sWord)
-        self._suggest2(oSuggResult)
-        aSugg = oSuggResult.getSuggestions(nSuggLimit)
-        if sSfx or sPfx:
-            # we add what we removed
-            return list(map(lambda sSug: sPfx + sSug + sSfx, aSugg))
-        return aSugg
-
-    def _suggest2 (self, oSuggResult, nDeep=0, iAddr=0, sNewWord=""):
-        # recursive function
-        #logging.info((nDeep * "  ") + sNewWord)
-        if nDeep >= oSuggResult.nDistLimit:
-            sCleanNewWord = cp.simplifyWord(sNewWord)
-            if st.distanceSift4(oSuggResult.sCleanWord[:len(sCleanNewWord)], sCleanNewWord) > oSuggResult.nDistLimit:
-                return
-        if int.from_bytes(self.byDic[iAddr:iAddr+self.nBytesArc], byteorder='big') & self._finalNodeMask:
-            oSuggResult.addSugg(sNewWord, nDeep)
-        for cChar, jAddr in self._getCharArcsWithPriority(iAddr, oSuggResult.sWord[nDeep:nDeep+1]):
-            self._suggest2(oSuggResult, nDeep+1, jAddr, sNewWord+cChar)
-        return
-
     def _getCharArcs (self, iAddr):
         "generator: yield all chars and addresses from node at address <iAddr>"
         for nVal, jAddr in self._getArcs(iAddr):
             if nVal <= self.nChar:
                 yield (self.dCharVal[nVal], jAddr)
 
-    def _getSimilarCharArcs (self, cChar, iAddr):
-        "generator: yield similar char of <cChar> and address of the following node"
-        for c in cp.d1to1.get(cChar, [cChar]):
-            if c in self.dChar:
-                jAddr = self._lookupArcNode(self.dChar[c], iAddr)
-                if jAddr:
-                    yield (c, jAddr)
-
-    def _getCharArcsWithPriority (self, iAddr, cChar):
-        if not cChar:
-            yield from self._getCharArcs(iAddr)
-        lTuple = list(self._getCharArcs(iAddr))
-        lTuple.sort(key=lambda t: 0  if t[0] in cp.d1to1.get(cChar, cChar)  else  1)
-        yield from lTuple
-
     def _getTails (self, iAddr, sTail="", n=2):
         "return a list of suffixes ending at a distance of <n> from <iAddr>"
         aTails = set()
